"""
ingest refiner ground truth

Revision ID: 3e89c3746b56
Revises: 036ebfdb9fa3
Create Date: 2018-12-03 14:08:08.368389

"""
from datetime import datetime
from io import BytesIO
import os
import tarfile
from tempfile import TemporaryDirectory

import boto3

from stumpf.importers.diva import grozper_activity_importer
from stumpf.importers.kw2json import read_all_activities
from stumpf.models import db, Video

# revision identifiers, used by Alembic.
revision = '3e89c3746b56'
down_revision = '036ebfdb9fa3'
branch_labels = None
depends_on = None

BUCKET = 'diva-stumpf-migration-data'
BATCH = f'migration-{datetime.now().isoformat()}'


def import_activity(activity, video):
    provenance = {
        'batch': BATCH,
        'migration': True,
        'refiner-ground-truth': True
    }
    grozper_activity_importer.import_activity_group(activity, video, provenance)


def import_video(bytes_):
    tarball = tarfile.open(fileobj=bytes_)
    with TemporaryDirectory() as tempdir:
        tarball.extractall(tempdir)
        assert len(os.listdir(tempdir)) == 1
        video_id = os.listdir(tempdir)[0]
        video = Video.query.get_or_404(video_id)

        activities = read_all_activities(os.path.join(tempdir, video_id))
        assert activities
        for activity in activities:
            import_activity(activity, video)


def upgrade():
    s3 = boto3.client('s3')
    resp = s3.list_objects(Bucket=BUCKET, Delimiter='/', Prefix=f'{revision}/')
    assert resp['Contents']
    for file_ in resp['Contents']:
        key = file_['Key']
        bytes_ = BytesIO()
        s3.download_fileobj(BUCKET, key, bytes_)
        bytes_.seek(0)
        import_video(bytes_)
    db.session.commit()


def downgrade():
    pass
